@@ -1,6 +1,6 @@
 # encoding: utf-8
 from django import template
-from django.utils.translation import ugettext as _
+from django.utils.translation import ugettext_lazy as _
 
 register = template.Library()
 
@@ -9,7 +9,8 @@ class HasProduct(template.Node):
         try:
             tag_name, product = token.split_contents()
         except ValueError:
-            raise template.TemplateSyntaxError, "%r tag requires exactly one argument" % token.contents.split()[0]
+            raise template.TemplateSyntaxError, "%r tag requires exactly one \
+argument" % token.contents.split()[0]
 
         nodelist = parser.parse(('endplusghop_has_product',))
         parser.delete_first_token()
@@ -27,8 +28,8 @@ def plusghop_has_product(parser, token, *args, **kwargs):
     return HasProduct(parser, token)
 
 def plugshop_currency(value):
-    if value is None: return ""
-
+    if value is None: 
+        return ""
     v = str(value)[::-1]
     return " ".join([v[i:i+3][::-1] for i in xrange(0, len(v), 3) ][::-1])
 register.filter('plugshop_currency', plugshop_currency)
